@@ -1,10 +1,6 @@
-package
-  Joe2Jim ;
+package Joe2Jim ;
  
 use Filter::Util::Call ;
-
-use strict ;
-use warnings ;
  
 sub import
 {
